package com.ruoyi.ibs.list.mapper;

import com.ruoyi.ibs.list.domain.FamilyMembersRecord;

import java.util.List;


/**
 * 建档家庭成员信息Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-20
 */
public interface FamilyMembersRecordMapper 
{
    /**
     * 查询建档家庭成员信息
     * 
     * @param custIdc 建档家庭成员信息主键
     * @return 建档家庭成员信息
     */
    public FamilyMembersRecord selectFamilyMembersRecordByCustIdc(String custIdc);

    /**
     * 查询建档家庭成员信息列表
     * 
     * @param familyMembersRecord 建档家庭成员信息
     * @return 建档家庭成员信息集合
     */
    public List<FamilyMembersRecord> selectFamilyMembersRecordList(FamilyMembersRecord familyMembersRecord);

    /**
     * 新增建档家庭成员信息
     * 
     * @param familyMembersRecord 建档家庭成员信息
     * @return 结果
     */
    public int insertFamilyMembersRecord(FamilyMembersRecord familyMembersRecord);

    /**
     * 修改建档家庭成员信息
     * 
     * @param familyMembersRecord 建档家庭成员信息
     * @return 结果
     */
    public int updateFamilyMembersRecord(FamilyMembersRecord familyMembersRecord);

    /**
     * 删除建档家庭成员信息
     * 
     * @param custIdc 建档家庭成员信息主键
     * @return 结果
     */
    public int deleteFamilyMembersRecordByCustIdc(String custIdc);

    /**
     * 批量删除建档家庭成员信息
     * 
     * @param custIdcs 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFamilyMembersRecordByCustIdcs(String[] custIdcs);
}
